Index: branches/2.8.x/CHANGELOG
===================================================================
--- branches/2.8.x/CHANGELOG	(revision 1550)
+++ branches/2.8.x/CHANGELOG	(revision 1551)
@@ -11,6 +11,11 @@
 ! = Update/Change
 
 =========================== add small Features 2.8.2 ==========================
+27 Dez-2011 Build 1551 Dietmar Woellbrink (Luisehahne)
++ add languages vars in languages files
++ add upload error mesages moduleinstall
++ add index.php if not exists in function createFolderProtectFile
+! corrected changed coding between login_form and forgot_form
 21 Dez-2011 Build 1550 Dietmar Woellbrink (Luisehahne)
 ! update php mailer to version 5.2
 19 Dez-2011 Build 1549 Dietmar Woellbrink (Luisehahne)
Index: branches/2.8.x/wb/admin/interface/version.php
===================================================================
--- branches/2.8.x/wb/admin/interface/version.php	(revision 1550)
+++ branches/2.8.x/wb/admin/interface/version.php	(revision 1551)
@@ -52,5 +52,5 @@
 
 // check if defined to avoid errors during installation (redirect to admin panel fails if PHP error/warnings are enabled)
 if(!defined('VERSION')) define('VERSION', '2.8.2');
-if(!defined('REVISION')) define('REVISION', '1550');
+if(!defined('REVISION')) define('REVISION', '1551');
 if(!defined('SP')) define('SP', 'SP2');
Index: branches/2.8.x/wb/admin/modules/install.php
===================================================================
--- branches/2.8.x/wb/admin/modules/install.php	(revision 1550)
+++ branches/2.8.x/wb/admin/modules/install.php	(revision 1551)
@@ -45,10 +45,34 @@
 $temp_file = $temp_dir . $_FILES['userfile']['name'];
 $temp_unzip = WB_PATH.'/temp/unzip/';
 
-// Try to upload the file to the temp dir
-if(!move_uploaded_file($_FILES['userfile']['tmp_name'], $temp_file))
-{
-	$admin->print_error($MESSAGE['GENERIC']['CANNOT_UPLOAD']);
+if(!$_FILES['userfile']['error']) {
+	// Try to upload the file to the temp dir
+	if(!move_uploaded_file($_FILES['userfile']['tmp_name'], $temp_file))
+	{
+		$admin->print_error($MESSAGE['GENERIC_BAD_PERMISSIONS']);
+	}
+} else {
+// index for language files
+	$key = 'UNKNOW_UPLOAD_ERROR';
+    switch ($error_code) {
+        case UPLOAD_ERR_INI_SIZE:
+            $key = 'UPLOAD_ERR_INI_SIZE';
+        case UPLOAD_ERR_FORM_SIZE:
+            $key = 'UPLOAD_ERR_FORM_SIZE';
+        case UPLOAD_ERR_PARTIAL:
+            $key = 'UPLOAD_ERR_PARTIAL';
+        case UPLOAD_ERR_NO_FILE:
+            $key = 'UPLOAD_ERR_NO_FILE';
+        case UPLOAD_ERR_NO_TMP_DIR:
+            $key = 'UPLOAD_ERR_NO_TMP_DIR';
+        case UPLOAD_ERR_CANT_WRITE:
+            $key = 'UPLOAD_ERR_CANT_WRITE';
+        case UPLOAD_ERR_EXTENSION:
+            $key = 'UPLOAD_ERR_EXTENSION';
+        default:
+            $key = 'UNKNOW_UPLOAD_ERROR';
+    }
+	$admin->print_error($MESSAGE[$key].'<br />'.$MESSAGE['GENERIC_CANNOT_UPLOAD']);
 }
 
 // Include the PclZip class file (thanks to 
@@ -65,7 +89,7 @@
 // Check if uploaded file is a valid Add-On zip file
 if (!($list && file_exists($temp_unzip . 'index.php')))
 {
-  $admin->print_error($MESSAGE['GENERIC']['INVALID_ADDON_FILE']);
+  $admin->print_error($MESSAGE['GENERIC_INVALID_ADDON_FILE']);
 }
 
 // Include the modules info file
Index: branches/2.8.x/wb/account/login_form.php
===================================================================
--- branches/2.8.x/wb/account/login_form.php	(revision 1550)
+++ branches/2.8.x/wb/account/login_form.php	(revision 1551)
@@ -4,6 +4,7 @@
  * @category        frontend
  * @package         account
  * @author          WebsiteBaker Project
+ * @copyright       2004-2009, Ryan Djurovich
  * @copyright       2009-2011, Website Baker Org. e.V.
  * @link			http://www.websitebaker2.org/
  * @license         http://www.gnu.org/licenses/gpl.html
@@ -17,107 +18,80 @@
 
 // Must include code to stop this file being access directly
 if(defined('WB_PATH') == false) { die("Cannot access this file directly"); }
-// Check if the user has already submitted the form, otherwise show it
-if(isset($_POST['email']) && $_POST['email'] != "" &&
-    preg_match("/([0-9a-zA-Z]+[-._+&])*[0-9a-zA-Z]+@([-0-9a-zA-Z]+[.])+[a-zA-Z]{2,6}/i", $_POST['email']))
-{
-	$email = strip_tags($_POST['email']);
-// Check if the email exists in the database
-	$sql  = 'SELECT `user_id`,`username`,`display_name`,`email`,`last_reset`,`password` '.
-	        'FROM `'.TABLE_PREFIX.'users` '.
-	        'WHERE `email`=\''.$wb->add_slashes($_POST['email']).'\'';
-	if(($results = $database->query($sql)))
-	{
-		if(($results_array = $results->fetchRow()))
-		{ // Get the id, username, email, and last_reset from the above db query
-		// Check if the password has been reset in the last 2 hours
-			if( (time() - (int)$results_array['last_reset']) < (2 * 3600) ) {
-			// Tell the user that their password cannot be reset more than once per hour
-				$message = $MESSAGE['FORGOT_PASS']['ALREADY_RESET'];
-			} else {
-				require_once(WB_PATH.'/framework/PasswordHash.php');
-				$pwh = new PasswordHash(0, true);
-				$old_pass = $results_array['password'];
-			// Generate a random password then update the database with it
-				$new_pass = $pwh->NewPassword();
-				$sql = 'UPDATE `'.TABLE_PREFIX.'users` '.
-				       'SET `password`=\''.$pwh->HashPassword($new_pass, true).'\', '.
-				           '`last_reset`='.time().' '.
-				       'WHERE `user_id`='.(int)$results_array['user_id'];
-				unset($pwh); // destroy $pwh-Object
-				if($database->query($sql))
-				{ // Setup email to send
-					$mail_to = $email;
-					$mail_subject = $MESSAGE['SIGNUP2_SUBJECT_LOGIN_INFO'];
-				// Replace placeholders from language variable with values
-					$search = array('{LOGIN_DISPLAY_NAME}', '{LOGIN_WEBSITE_TITLE}', '{LOGIN_NAME}', '{LOGIN_PASSWORD}');
-					$replace = array($results_array['display_name'], WEBSITE_TITLE, $results_array['username'], $new_pass);
-					$mail_message = str_replace($search, $replace, $MESSAGE['SIGNUP2_BODY_LOGIN_FORGOT']);
-				// Try sending the email
-					if($wb->mail(SERVER_EMAIL,$mail_to,$mail_subject,$mail_message)) {
-						$message = $MESSAGE['FORGOT_PASS_PASSWORD_RESET'];
-						$display_form = false;
-					}else { // snd mail failed, rollback
-						$sql = 'UPDATE `'.TABLE_PREFIX.'users` '.
-						       'SET `password`=\''.$old_pass.'\' '.
-						       'WHERE `user_id`='.(int)$results_array['user_id'];
-						$database->query($sql);
-						$message = $MESSAGE['FORGOT_PASS_CANNOT_EMAIL'];
-					}
-				}else { // Error updating database
-					$message = $MESSAGE['RECORD_MODIFIED_FAILED'];
-					if(DEBUG) {
-						$message .= '<br />'.$database->get_error();
-						$message .= '<br />'.$sql;
-					}
-				}
-			}
-		}else { // no record found - Email doesn't exist, so tell the user
-			$message = $MESSAGE['FORGOT_PASS_EMAIL_NOT_FOUND'];
-		}
-	} else { // Query failed
-		$message = 'SystemError:: Database query failed!';
-		if(DEBUG) {
-			$message .= '<br />'.$database->get_error();
-			$message .= '<br />'.$sql;
-		}
+
+$username_fieldname = 'username';
+$password_fieldname = 'password';
+
+if(defined('SMART_LOGIN') AND SMART_LOGIN == 'enabled') {
+	// Generate username field name
+	$username_fieldname = 'username_';
+	$password_fieldname = 'password_';
+
+	$temp = array_merge(range('a','z'), range(0,9));
+	shuffle($temp);
+	for($i=0;$i<=7;$i++) {
+		$username_fieldname .= $temp[$i];
+		$password_fieldname .= $temp[$i];
 	}
-} else {
-	$email = '';
 }
 
-if(isset($message) && $message != '') {
-	$message_color = 'FF0000';
-} else {
-	$message = $MESSAGE['FORGOT_PASS_NO_DATA'];
-	$message_color = '000000';
-}
-
-$_SESSION['PAGE_LINK'] = get_page_link( $_SESSION['PAGE_ID'] );
-$_SESSION['HTTP_REFERER'] = page_link($_SESSION['PAGE_LINK']);
-	
+$page_id = !empty($_SESSION['PAGE_ID']) ? $_SESSION['PAGE_ID'] : 0;
+$_SESSION['PAGE_LINK'] = get_page_link( $page_id );
+if(!file_exists($_SESSION['PAGE_LINK'])) {$_SESSION['PAGE_LINK'] = WB_URL.'/'; }
+$_SESSION['HTTP_REFERER'] = $_SESSION['PAGE_LINK'];
+$thisApp->redirect_url = (isset($thisApp->redirect_url) ? $thisApp->redirect_url : $_SESSION['PAGE_LINK'])
 ?>
 <div style="margin: 1em auto;">
 	<button type="button" value="cancel" onClick="javascript: window.location = '<?php print $_SESSION['HTTP_REFERER'] ?>';"><?php print $TEXT['CANCEL'] ?></button>
 </div>
-<h1 style="text-align: center;"><?php echo $MENU['FORGOT']; ?></h1>
-<form name="forgot_pass" action="<?php echo WB_URL.'/account/forgot.php'; ?>" method="post">
-	<input type="hidden" name="url" value="{URL}" />
-		<table cellpadding="5" cellspacing="0" border="0" align="center" width="500">
-		<tr>
-			<td height="40" align="center" style="color: #<?php echo $message_color; ?>;" colspan="2">
-			<?php echo $message; ?>
-			</td>
-		</tr>
-<?php if(!isset($display_form) OR $display_form != false) { ?>
-		<tr>
-			<td height="10" colspan="2"></td>
-		</tr>
-		<tr>
-			<td width="165" height="30" align="right"><?php echo $TEXT['EMAIL']; ?>:</td>
-			<td><input type="text" maxlength="255" name="email" value="<?php echo $email; ?>" style="width: 180px;" /></td>
-			<td><input type="submit" name="submit" value="<?php echo $TEXT['SEND_DETAILS']; ?>" style="width: 180px; font-size: 10px; color: #003366; border: 1px solid #336699; background-color: #DDDDDD; padding: 3px; text-transform: uppercase;" /></td>
-		</tr>
+<h1>&nbsp;Login</h1>
+&nbsp;<?php echo $thisApp->message; ?>
+<br />
+<br />
+
+<form class="login-box" action="<?php echo WB_URL.'/account/login.php'; ?>" method="post">
+<input type="hidden" name="username_fieldname" value="<?php echo $username_fieldname; ?>" />
+<input type="hidden" name="password_fieldname" value="<?php echo $password_fieldname; ?>" />
+<input type="hidden" name="redirect" value="<?php echo $thisApp->redirect_url;?>" />
+
+<table cellpadding="5" cellspacing="0" border="0" width="90%">
+<tr>
+	<td style="width:100px"><?php echo $TEXT['USERNAME']; ?>:</td>
+	<td class="value_input">
+		<input type="text" name="<?php echo $username_fieldname; ?>" maxlength="30" style="width:220px;"/>
+    	<script type="text/javascript">
+    	// document.login.<?php echo $username_fieldname; ?>.focus();
+    	var ref= document.getElementById("<?php echo $username_fieldname; ?>");
+    	if (ref) ref.focus();
+    	</script>
+	</td>
+</tr>
+<tr>
+	<td style="width:100px"><?php echo $TEXT['PASSWORD']; ?>:</td>
+	<td class="value_input">
+		<input type="password" name="<?php echo $password_fieldname; ?>" maxlength="30" style="width:220px;"/>
+	</td>
+</tr>
+<?php if($username_fieldname != 'username') { ?>
+<tr>
+	<td>&nbsp;</td>
+	<td>
+		<input type="checkbox" name="remember" id="remember" value="true"/>
+		<label for="remember"><?php echo $TEXT['REMEMBER_ME']; ?></label>
+	</td>
+</tr>
 <?php } ?>
-		</table>
-</form>
\ No newline at end of file
+<tr>
+	<td>&nbsp;</td>
+	<td>
+		<input type="submit" name="submit" value="<?php echo $TEXT['LOGIN']; ?>"  />
+		<input type="reset" name="reset" value="<?php echo $TEXT['RESET']; ?>"  />
+	</td>
+</tr>
+</table>
+
+</form>
+
+<br />
+
+<a href="<?php echo WB_URL; ?>/account/forgot.php"><?php echo $TEXT['FORGOTTEN_DETAILS']; ?></a>
\ No newline at end of file
Index: branches/2.8.x/wb/framework/functions.php
===================================================================
--- branches/2.8.x/wb/framework/functions.php	(revision 1550)
+++ branches/2.8.x/wb/framework/functions.php	(revision 1551)
@@ -680,16 +680,18 @@
 		$filename = $sAbsDir.'/index.php';
 
 		// write content into file
-		if(is_writable($filename)) {
-		    if(file_put_contents($filename, $content)) {
-				print 'create => '.str_replace( $wb_path,'',$filename).'<br />';
-		        change_mode($filename, 'file');
-		    }
-		}
-	} else {
-			$retVal[] = $MESSAGE['GENERIC_BAD_PERMISSIONS'];
-	}
-	return $retVal;
+		  if(is_writable($filename) || !file_exists($filename)) {
+		      if(file_put_contents($filename, $content)) {
+		//    print 'create => '.str_replace( $wb_path,'',$filename).'<br />';
+		          change_mode($filename, 'file');
+		      }else {
+		    $retVal[] = $MESSAGE['GENERIC_BAD_PERMISSIONS'].' :: '.$filename;
+		   }
+		  }
+		 } else {
+		   $retVal[] = $MESSAGE['GENERIC_BAD_PERMISSIONS'];
+		 }
+		 return $retVal;
 }
 
 function rebuildFolderProtectFile($dir='')
Index: branches/2.8.x/wb/languages/FI.php
===================================================================
--- branches/2.8.x/wb/languages/FI.php	(revision 1550)
+++ branches/2.8.x/wb/languages/FI.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Tervetuloa sivuston hallintaan';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Sivupohjan voi vaihtaa asetukset-kohdasta';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Lis&auml;tty';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Jos haluat vaihtaa salasanan, t&auml;yt&auml; vain ko kent&auml;t';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/EN.php
===================================================================
--- branches/2.8.x/wb/languages/EN.php	(revision 1550)
+++ branches/2.8.x/wb/languages/EN.php	(revision 1551)
@@ -540,7 +540,7 @@
 $MESSAGE['MEDIA_TARGET_DOT_DOT_SLASH'] = 'Cannot have ../ in the folder target';
 $MESSAGE['MEDIA_UPLOADED'] = ' files were successfully uploaded';
 $MESSAGE['MOD_FORM_EXCESS_SUBMISSIONS'] = 'Sorry, this form has been submitted too many times so far this hour. Please retry in the next hour.';
-$MESSAGE['MOD_FORM_INCORRECT_CAPTCHA'] = 'The verification number (also known as Captcha) that you entered is incorrect. If you are having problems reading the Captcha, please email: <a href="mailto:'.SERVER_EMAIL.'">'.SERVER_EMAIL.'</a>';
+$MESSAGE['MOD_FORM_INCORRECT_CAPTCHA'] = 'The verification number (also known as Captcha) that you entered is incorrect. If you are having problems reading the Captcha, please email: <a href="mailto:'.'.SERVER_EMAIL.'.'">'.'.SERVER_EMAIL.'.'</a>';
 $MESSAGE['MOD_FORM_REQUIRED_FIELDS'] = 'You must enter details for the following fields';
 $MESSAGE['PAGES_ADDED'] = 'Page added successfully';
 $MESSAGE['PAGES_ADDED_HEADING'] = 'Page heading added successfully';
@@ -635,6 +635,17 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Welcome to WebsiteBaker Administration';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Please note: to change the template you must go to the Settings section';
+
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+
 $MESSAGE['USERS_ADDED'] = 'User added successfully';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Please note: You should only enter values in the above fields if you wish to change this users password';
@@ -669,4 +680,4 @@
 if(file_exists(WB_PATH.'/languages/old.format.inc.php'))
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
-}
\ No newline at end of file
+}
Index: branches/2.8.x/wb/languages/CS.php
===================================================================
--- branches/2.8.x/wb/languages/CS.php	(revision 1550)
+++ branches/2.8.x/wb/languages/CS.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'V&iacute;tejte v Administra&#269;n&iacute; &#269;&aacute;sti';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Pozn.: zm&#283;na &scaron;ablony se prov&aacute;d&iacute; v sekci Nastaven&iacute;';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'U&#382;ivatel byl &uacute;sp&#283;&scaron;n&#283; p&#345;id&aacute;n';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Pozn.: vypl&#328;te pouze hodnoty v&yacute;&scaron;e pokud si p&#345;ejete zm&#283;nit heslo';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/SE.php
===================================================================
--- branches/2.8.x/wb/languages/SE.php	(revision 1550)
+++ branches/2.8.x/wb/languages/SE.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'V&auml;lkommen till administrationen av WebsiteBaker';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Observera: f&ouml;r att &auml;ndra Mall, m&aring;ste du g&aring; till Sektionen Inst&auml;llningar';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Anv&auml;ndaren lades till';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Observera: Dessa f&auml;lt ska du bara skriva i om du vill &Auml;NDRA L&ouml;senordet';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/ES.php
===================================================================
--- branches/2.8.x/wb/languages/ES.php	(revision 1550)
+++ branches/2.8.x/wb/languages/ES.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Bienvenido a la consola de Administraci&oacute;n';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Atenci&oacute;n: para cambiar la plantilla ir a la secci&oacute;n de Configuraci&oacute;n';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Nuevo usuario agregado';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Atenci&oacute;n: Solo debe escribir en estos campos si desea cambiar la contrase&ntilde;a de este usuario.';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/FR.php
===================================================================
--- branches/2.8.x/wb/languages/FR.php	(revision 1550)
+++ branches/2.8.x/wb/languages/FR.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Bienvenue dans la zone d&apos;administration';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Pour modifier le th&egrave;me du site, vous devez vous rendre dans la rubrique R&eacute;glages';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Utilisateur ajout&eacute; avec succ&egrave;s';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Action refus&eacute;e, Vous ne pouvez pas vous supprimer vous-m&ecirc;me!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Vous ne devez modifier les valeurs ci-dessus uniquement lors d&apos;une modification de mot de passe';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/ET.php
===================================================================
--- branches/2.8.x/wb/languages/ET.php	(revision 1550)
+++ branches/2.8.x/wb/languages/ET.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Teretulemast WebsiteBaker Administratsiooni';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'M&auml;rge: kujunduse muutmiseks sa pead minema Seadete sektsiooni';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Kasutaja edukalt lisatud';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'M&auml;rge: Sa pead ainult sisestama p&otilde;him&otilde;tted alumistesse lahtritesse kui sa tahad muuta selle kasutaja parooli';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/HR.php
===================================================================
--- branches/2.8.x/wb/languages/HR.php	(revision 1550)
+++ branches/2.8.x/wb/languages/HR.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Dobro do&scaron;li u WebsiteBaker administraciju';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Obavijest: Za promjenu predlo&scaron;ka idite na dio s Postavkama';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Korisnik je dodan supje&scaron;no';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Obavijest: Trebate samo unjeti vrijednosti u polja ispod ako &#382;elite izmjeniti korisni&egrave;ku lozinku';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/NL.php
===================================================================
--- branches/2.8.x/wb/languages/NL.php	(revision 1550)
+++ branches/2.8.x/wb/languages/NL.php	(revision 1551)
@@ -633,6 +633,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Welkom bij het websitebeheer';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Attentie: om de template aan te passen moet u naar de instellingensectie';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Gebruiker toegevoegd';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Functie geweigerd. U kunt zichzelf niet verwijderen!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Attentie: vul alleen de bovenstaande velden in wanneer u het wachtwoord van de gebruiker wilt veranderen';
@@ -668,4 +677,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/PL.php
===================================================================
--- branches/2.8.x/wb/languages/PL.php	(revision 1550)
+++ branches/2.8.x/wb/languages/PL.php	(revision 1551)
@@ -634,6 +634,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Witamy w panelu administracyjnym WebsiteBakera';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Uwaga: aby zmienic szablon, nalezy przejsc do sekcji Ustawienia';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Uzytkownik zostal dodany';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Zadanie odrzucone, Nie mozesz usunac sam siebie!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Uwaga: Powyzsze pola nalezy wypelnic tylko, jesli chce sie zmienic haslo tego uzytkownika';
@@ -669,4 +678,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/HU.php
===================================================================
--- branches/2.8.x/wb/languages/HU.php	(revision 1550)
+++ branches/2.8.x/wb/languages/HU.php	(revision 1551)
@@ -35,7 +35,7 @@
 /* MENU */
 $MENU['ACCESS'] = 'Jogosults&aacute;gok';
 $MENU['ADDON'] = 'Add-on';
-$MENU['ADDONS'] = 'Kieg&eacute;sz&iacute;t╨Ф┬л';
+$MENU['ADDONS'] = 'Kieg&eacute;sz&iacute;t-?-?';
 $MENU['ADMINTOOLS'] = 'Admin-Eszk&ouml;z&ouml;k';
 $MENU['BREADCRUMB'] = 'You are here: ';
 $MENU['FORGOT'] = 'Elfelejtett jelsz&oacute;';
@@ -50,7 +50,7 @@
 $MENU['PAGES'] = 'Weblapok';
 $MENU['PREFERENCES'] = 'Saj&aacute;t adatok';
 $MENU['SETTINGS'] = 'Param&eacute;terek';
-$MENU['START'] = 'Kezd╨Ф┬мap';
+$MENU['START'] = 'Kezd-?-?ap';
 $MENU['TEMPLATES'] = 'Sablonok';
 $MENU['USERS'] = 'Felhaszn&aacute;l&oacute;k';
 $MENU['VIEW'] = 'Port&aacute;l n&eacute;zet';
@@ -67,7 +67,7 @@
 $TEXT['ADMINISTRATION_TOOL'] = 'Adminisztr&aacute;ci&oacute;s Eszk&ouml;z';
 $TEXT['ADMINISTRATOR'] = 'Administrator';
 $TEXT['ADMINISTRATORS'] = 'Adminisztr&aacute;torok';
-$TEXT['ADVANCED'] = 'B╨Ф┬╢&iacute;tett';
+$TEXT['ADVANCED'] = 'B-?-¦&iacute;tett';
 $TEXT['ALLOWED_FILETYPES_ON_UPLOAD'] = 'Allowed filetypes on upload';
 $TEXT['ALLOWED_VIEWERS'] = 'Enged&eacute;lyezett l&aacute;togat&oacute;k';
 $TEXT['ALLOW_MULTIPLE_SELECTIONS'] = 'T&ouml;bbet is kiv&aacute;laszthat';
@@ -134,7 +134,7 @@
 $TEXT['EXACT_MATCH'] = 'Pontos egyez&eacute;s';
 $TEXT['EXECUTE'] = 'V&eacute;grehajt&aacute;s';
 $TEXT['EXPAND'] = 'Kibont';
-$TEXT['EXTENSION'] = 'B╨Ф┬╢&iacute;tm&eacute;ny';
+$TEXT['EXTENSION'] = 'B-?-¦&iacute;tm&eacute;ny';
 $TEXT['FIELD'] = 'Mez&ccedil;';
 $TEXT['FILE'] = 'F&aacute;jl';
 $TEXT['FILES'] = 'F&aacute;jlok';
@@ -158,7 +158,7 @@
 $TEXT['HIDDEN'] = 'Rejtett';
 $TEXT['HIDE'] = 'Elrejt';
 $TEXT['HIDE_ADVANCED'] = 'Speci&aacute;lis be&aacute;ll&iacute;t&aacute;sok elrejt&eacute;se';
-$TEXT['HOME'] = 'Kezd╨Ф┬мap';
+$TEXT['HOME'] = 'Kezd-?-?ap';
 $TEXT['HOMEPAGE_REDIRECTION'] = 'Honlap &aacute;tir&aacute;ny&iacute;t&aacute;s';
 $TEXT['HOME_FOLDER'] = 'Personal Folder';
 $TEXT['HOME_FOLDERS'] = 'Personal Folders';
@@ -184,9 +184,9 @@
 $TEXT['LIST_OPTIONS'] = 'Lista opci&oacute;k';
 $TEXT['LOGGED_IN'] = 'Bejelentkezve';
 $TEXT['LOGIN'] = 'Bel&eacute;p&eacute;s';
-$TEXT['LONG'] = 'Hossz╨Х┬▒';
+$TEXT['LONG'] = 'Hossz-?-¦';
 $TEXT['LONG_TEXT'] = 'Hossz&uacute; sz&ouml;veg';
-$TEXT['LOOP'] = 'ism&eacute;tl╨Ф┬д&uuml;/br&gt; t&ouml;rzs szakasz';
+$TEXT['LOOP'] = 'ism&eacute;tl-?-?&uuml;/br&gt; t&ouml;rzs szakasz';
 $TEXT['MAIN'] = 'F&ccedil;';
 $TEXT['MAINTENANCE_OFF'] = 'Maintenance off';
 $TEXT['MAINTENANCE_ON'] = 'Maintenance on';
@@ -208,10 +208,10 @@
 $TEXT['MODIFY_SETTINGS'] = 'Be&aacute;ll&iacute;t&aacute;sok m&oacute;dos&iacute;t&aacute;sa';
 $TEXT['MODULE_ORDER'] = 'Modul sorrend keres&eacute;sn&eacute;l';
 $TEXT['MODULE_PERMISSIONS'] = 'Modul enged&eacute;lyek';
-$TEXT['MORE'] = 'B╨Ф┬╢ebben';
+$TEXT['MORE'] = 'B-?-¦ebben';
 $TEXT['MOVE_DOWN'] = 'Mozgat Le';
 $TEXT['MOVE_UP'] = 'Mozgat Fel';
-$TEXT['MULTIPLE_MENUS'] = 'T&ouml;bbszint╨Х┬▒ men&uuml;';
+$TEXT['MULTIPLE_MENUS'] = 'T&ouml;bbszint-?-¦ men&uuml;';
 $TEXT['MULTISELECT'] = 'T&ouml;bb v&aacute;laszt&aacute;sos';
 $TEXT['NAME'] = 'N&eacute;v';
 $TEXT['NEED_CURRENT_PASSWORD'] = 'confirm with current password';
@@ -256,8 +256,8 @@
 $TEXT['POSTS_PER_PAGE'] = '&ordm;enetek laponk&eacute;nt';
 $TEXT['POST_FOOTER'] = '&ordm;enet l&aacute;bl&eacute;c';
 $TEXT['POST_HEADER'] = '&ordm;enet fejbl&eacute;c';
-$TEXT['PREVIOUS'] = 'El╨Ф╤Ф&ccedil;';
-$TEXT['PREVIOUS_PAGE'] = 'El╨Ф╤Ф&agrave;oldal';
+$TEXT['PREVIOUS'] = 'El-?-?&ccedil;';
+$TEXT['PREVIOUS_PAGE'] = 'El-?-?&agrave;oldal';
 $TEXT['PRIVATE'] = 'Priv&aacute;t';
 $TEXT['PRIVATE_VIEWERS'] = 'Priv&aacute;t jogosultak';
 $TEXT['PROFILES_EDIT'] = 'Change the profile';
@@ -321,7 +321,7 @@
 $TEXT['SUCCESS'] = 'Sikeres';
 $TEXT['SYSTEM_DEFAULT'] = 'Rendszer alap&eacute;rtelmezett';
 $TEXT['SYSTEM_PERMISSIONS'] = 'Rendszer enged&eacute;lyek';
-$TEXT['TABLE_PREFIX'] = 'T&aacute;bla el╨Ф╥Сag';
+$TEXT['TABLE_PREFIX'] = 'T&aacute;bla el-?-?ag';
 $TEXT['TARGET'] = 'C&eacute;l';
 $TEXT['TARGET_FOLDER'] = 'C&eacute;l k&ouml;nyvt&aacute;r';
 $TEXT['TEMPLATE'] = 'Weboldal Sablon';
@@ -331,7 +331,7 @@
 $TEXT['TEXTFIELD'] = 'Sz&ouml;vegmez&ccedil;';
 $TEXT['THEME'] = 'Admin T&eacute;ma';
 $TEXT['TIME'] = 'Id&ccedil;';
-$TEXT['TIMEZONE'] = 'Id╨Ф╤Ф&oacute;na';
+$TEXT['TIMEZONE'] = 'Id-?-?&oacute;na';
 $TEXT['TIME_FORMAT'] = 'Id&agrave;form&aacute;tum';
 $TEXT['TIME_LIMIT'] = 'Maxim&aacute;lis id&agrave;a modulonk&eacute;nti tal&aacute;latra';
 $TEXT['TITLE'] = 'C&iacute;m';
@@ -365,9 +365,9 @@
 $TEXT['VISIBILITY'] = 'Megjelen&eacute;s';
 $TEXT['WBMAILER_DEFAULT_SENDER_MAIL'] = 'K&uuml;ld&agrave;email';
 $TEXT['WBMAILER_DEFAULT_SENDER_NAME'] = 'K&uuml;ld&agrave;szem&eacute;ly';
-$TEXT['WBMAILER_DEFAULT_SETTINGS_NOTICE'] = 'K&eacute;rlek add meg az alap&eacute;rtelmezett "K&uuml;ld&agrave;email" c&iacute;met &eacute;s a "K&uuml;ld&agrave;szem&eacute;ly" mez╨Ф╥С. Aj&aacute;nlott az al&aacute;bbi foszn&aacute;lata: &lt;strong&gt;admin@tedomained.hu&lt;/strong&gt;. N&eacute;mely szolg&aacute;ltat&oacute; (e.g. &lt;em&gt;mail.com&lt;/em&gt;) Visszautas&iacute;thatja a leveleket az olyan k&uuml;ld&agrave;c&iacute;mt╨Ф┬м mint &lt;@mail.com&lt;/em&gt; ez az&eacute;rt van hogy megakad&aacute;lyozz&aacute;k a SPAM k&uuml;ld&eacute;st.&lt;br /&gt;&lt;br /&gt;Az alap&eacute;rtelmezett &eacute;rt&eacute;kek csak akkor &eacute;rv&eacute;nyesek,ha nincs m&aacute;s megadva aker-ben. Ha a szervered t&aacute;mogatja &lt;acronym title="Simple mail transfer protocol"&gt;SMTP&lt;/acronym&gt;protokolt, akkor haszn&aacute;lhatod ezt az opci&oacute;t lev&eacute;l k&uuml;ld&eacute;;hez.';
+$TEXT['WBMAILER_DEFAULT_SETTINGS_NOTICE'] = 'K&eacute;rlek add meg az alap&eacute;rtelmezett "K&uuml;ld&agrave;email" c&iacute;met &eacute;s a "K&uuml;ld&agrave;szem&eacute;ly" mez-?-?. Aj&aacute;nlott az al&aacute;bbi foszn&aacute;lata: &lt;strong&gt;admin@tedomained.hu&lt;/strong&gt;. N&eacute;mely szolg&aacute;ltat&oacute; (e.g. &lt;em&gt;mail.com&lt;/em&gt;) Visszautas&iacute;thatja a leveleket az olyan k&uuml;ld&agrave;c&iacute;mt-?-? mint &lt;@mail.com&lt;/em&gt; ez az&eacute;rt van hogy megakad&aacute;lyozz&aacute;k a SPAM k&uuml;ld&eacute;st.&lt;br /&gt;&lt;br /&gt;Az alap&eacute;rtelmezett &eacute;rt&eacute;kek csak akkor &eacute;rv&eacute;nyesek,ha nincs m&aacute;s megadva aker-ben. Ha a szervered t&aacute;mogatja &lt;acronym title="Simple mail transfer protocol"&gt;SMTP&lt;/acronym&gt;protokolt, akkor haszn&aacute;lhatod ezt az opci&oacute;t lev&eacute;l k&uuml;ld&eacute;;hez.';
 $TEXT['WBMAILER_FUNCTION'] = 'Mail Rutin';
-$TEXT['WBMAILER_NOTICE'] = '&lt;strong&gt;SMTP Mailer Be&aacute;ll&iacute;t&aacute;sok:&lt;/strong&gt;&lt;br /&gt;Ezek a be&aacute;ll&iacute;t&aacute;sok csak akkor sz&uuml;ks&eacute;gesek, ha emailt akarsz k&uuml;ldeni &lt;acro="Simple mail transfer protocol"&gt;SMTP&lt;/acronym&gt; protokollon kereszt&uuml;l. Ha nem tudod az SMTP kiszolg&aacute;l&oacute;dat, vagy nem vagy biztos a k&ouml;vetlem&eacute;nyekben, akkoszer╨Х┬▒en maradj az alap be&aacute;ll&iacute;t&aacute;sn&aacute;l: PHP MAIL.';
+$TEXT['WBMAILER_NOTICE'] = '&lt;strong&gt;SMTP Mailer Be&aacute;ll&iacute;t&aacute;sok:&lt;/strong&gt;&lt;br /&gt;Ezek a be&aacute;ll&iacute;t&aacute;sok csak akkor sz&uuml;ks&eacute;gesek, ha emailt akarsz k&uuml;ldeni &lt;acro="Simple mail transfer protocol"&gt;SMTP&lt;/acronym&gt; protokollon kereszt&uuml;l. Ha nem tudod az SMTP kiszolg&aacute;l&oacute;dat, vagy nem vagy biztos a k&ouml;vetlem&eacute;nyekben, akkoszer-?-¦en maradj az alap be&aacute;ll&iacute;t&aacute;sn&aacute;l: PHP MAIL.';
 $TEXT['WBMAILER_PHP'] = 'PHP MAIL';
 $TEXT['WBMAILER_SMTP'] = 'SMTP';
 $TEXT['WBMAILER_SMTP_AUTH'] = 'SMTP Azonos&iacute;t&aacute;s';
@@ -392,7 +392,7 @@
 $TEXT['YES'] = 'Igen';
 
 /* HEADING */
-$HEADING['ADDON_PRECHECK_FAILED'] = 'Kieg&eacute;sz&iacute;t&agrave;k&ouml;vetelm&eacute;nyek nem megfelel╨Ф╥Рk';
+$HEADING['ADDON_PRECHECK_FAILED'] = 'Kieg&eacute;sz&iacute;t&agrave;k&ouml;vetelm&eacute;nyek nem megfelel-?-?k';
 $HEADING['ADD_CHILD_PAGE'] = 'Add child page';
 $HEADING['ADD_GROUP'] = 'Csoport m&oacute;dos&iacute;t&aacute;sa';
 $HEADING['ADD_GROUPS'] = 'Add Groups';
@@ -475,12 +475,12 @@
 $MESSAGE['GENERIC_FAILED_COMPARE'] = ' failed';
 $MESSAGE['GENERIC_FILE_TYPE'] = 'A felt&ouml;lt&ouml;tt file csak ilyen form&aacute;tum&uacute; lehet:';
 $MESSAGE['GENERIC_FILE_TYPES'] = 'A felt&ouml;lt&ouml;tt file-ok csak a k&ouml;vetkez&agrave;form&aacute;tumuak lehetnek:';
-$MESSAGE['GENERIC_FILL_IN_ALL'] = 'K&eacute;rem t&eacute;rjen vissza &eacute;s t&ouml;lts&ouml;n ki minden mez╨Ф╥С';
+$MESSAGE['GENERIC_FILL_IN_ALL'] = 'K&eacute;rem t&eacute;rjen vissza &eacute;s t&ouml;lts&ouml;n ki minden mez-?-?';
 $MESSAGE['GENERIC_FORGOT_OPTIONS'] = 'You have selected no choice!';
 $MESSAGE['GENERIC_INSTALLED'] = 'Telep&iacute;t&eacute;s sikeres';
 $MESSAGE['GENERIC_INVALID'] = 'A felt&ouml;lt&ouml;tt file nem megfelel&ccedil;';
-$MESSAGE['GENERIC_INVALID_ADDON_FILE'] = '&sup2;v&eacute;nytelen WebsiteBaker telep&iacute;t&agrave;f&aacute;jl. K&eacute;rlek ellen╨Ф╨Жizd a *.zip form&aacute;tumot.';
-$MESSAGE['GENERIC_INVALID_LANGUAGE_FILE'] = '&sup2;v&eacute;nytelen WebsiteBaker nyelvi f&aacute;jl. K&eacute;rlek ellen╨Ф╨Жizd a sz&ouml;veges f&aacute;jlt.';
+$MESSAGE['GENERIC_INVALID_ADDON_FILE'] = '&sup2;v&eacute;nytelen WebsiteBaker telep&iacute;t&agrave;f&aacute;jl. K&eacute;rlek ellen-?-?izd a *.zip form&aacute;tumot.';
+$MESSAGE['GENERIC_INVALID_LANGUAGE_FILE'] = '&sup2;v&eacute;nytelen WebsiteBaker nyelvi f&aacute;jl. K&eacute;rlek ellen-?-?izd a sz&ouml;veges f&aacute;jlt.';
 $MESSAGE['GENERIC_INVALID_MODULE_FILE'] = 'Invalid WebsiteBaker module file. Please check the text file.';
 $MESSAGE['GENERIC_INVALID_TEMPLATE_FILE'] = 'Invalid WebsiteBaker template file. Please check the text file.';
 $MESSAGE['GENERIC_IN_USE'] = ' but used in ';
@@ -490,7 +490,7 @@
 $MESSAGE['GENERIC_NOT_INSTALLED'] = 'Nincs telp&iacute;tve';
 $MESSAGE['GENERIC_NOT_UPGRADED'] = 'Actualization not possibly';
 $MESSAGE['GENERIC_PLEASE_BE_PATIENT'] = 'K&eacute;rem v&aacute;rjon, ez eltarthat egy ideig.';
-$MESSAGE['GENERIC_PLEASE_CHECK_BACK_SOON'] = 'K&eacute;rem t&eacute;rjen vissza k&eacute;s╨Ф╤Юb!';
+$MESSAGE['GENERIC_PLEASE_CHECK_BACK_SOON'] = 'K&eacute;rem t&eacute;rjen vissza k&eacute;s-?-?b!';
 $MESSAGE['GENERIC_SECURITY_ACCESS'] = 'Security offense!! Access denied!';
 $MESSAGE['GENERIC_SECURITY_OFFENSE'] = 'Security offense!! data storing was refused!!';
 $MESSAGE['GENERIC_UNINSTALLED'] = 'Elt&aacute;vol&iacute;t&aacute;s sikeres';
@@ -501,7 +501,7 @@
 $MESSAGE['GENERIC_WEBSITE_LOCKED'] = 'this site is temporarily down for maintenance';
 $MESSAGE['GENERIC_WEBSITE_UNDER_CONSTRUCTION'] = 'A Weboldal Karbantart&aacute;s Alatt';
 $MESSAGE['GROUPS_ADDED'] = 'Csoport sikeresen hozz&aacute;adva';
-$MESSAGE['GROUPS_CONFIRM_DELETE'] = 'Biztos, hogy t&ouml;r&ouml;lni akarja a kijel&ouml;lt csoportot? (Minden felhaszn&aacute;l&oacute;ja t&ouml;rl╨Ф┬дik)';
+$MESSAGE['GROUPS_CONFIRM_DELETE'] = 'Biztos, hogy t&ouml;r&ouml;lni akarja a kijel&ouml;lt csoportot? (Minden felhaszn&aacute;l&oacute;ja t&ouml;rl-?-?ik)';
 $MESSAGE['GROUPS_DELETED'] = 'Csoport t&ouml;r&ouml;lve';
 $MESSAGE['GROUPS_GROUP_NAME_BLANK'] = '&sup2;es a csoportn&eacute;v';
 $MESSAGE['GROUPS_GROUP_NAME_EXISTS'] = 'Csoport n&eacute;v m&aacute;r l&eacute;tezik';
@@ -524,12 +524,12 @@
 $MESSAGE['MEDIA_DELETED_DIR'] = 'K&ouml;nyvt&aacute;r t&ouml;r&ouml;lve';
 $MESSAGE['MEDIA_DELETED_FILE'] = 'File t&ouml;r&ouml;lve';
 $MESSAGE['MEDIA_DIR_ACCESS_DENIED'] = 'Specified directory does not exist or is not allowed.';
-$MESSAGE['MEDIA_DIR_DOES_NOT_EXIST'] = 'Nem lehet ../ a c&eacute;l mez╨Ф╤Юen';
+$MESSAGE['MEDIA_DIR_DOES_NOT_EXIST'] = 'Nem lehet ../ a c&eacute;l mez-?-?en';
 $MESSAGE['MEDIA_DIR_DOT_DOT_SLASH'] = 'Nem tartalmazhat ../ -t a k&ouml;nyvt&aacute;r n&eacute;v';
-$MESSAGE['MEDIA_DIR_EXISTS'] = 'Ilyen nev╨Х┬▒ k&ouml;nyvt&aacute;r m&aacute;r l&eacute;tezik';
+$MESSAGE['MEDIA_DIR_EXISTS'] = 'Ilyen nev-?-¦ k&ouml;nyvt&aacute;r m&aacute;r l&eacute;tezik';
 $MESSAGE['MEDIA_DIR_MADE'] = 'A k&ouml;nyvt&aacute;r sikeresen l&eacute;trehozva';
 $MESSAGE['MEDIA_DIR_NOT_MADE'] = 'nem siker&uuml;lt l&eacute;trehozni a k&ouml;nyvt&aacute;rat';
-$MESSAGE['MEDIA_FILE_EXISTS'] = 'Ilyen nev╨Х┬▒ file m&aacute;r l&eacute;tezik';
+$MESSAGE['MEDIA_FILE_EXISTS'] = 'Ilyen nev-?-¦ file m&aacute;r l&eacute;tezik';
 $MESSAGE['MEDIA_FILE_NOT_FOUND'] = 'File nem tal&aacute;lhat&oacute;';
 $MESSAGE['MEDIA_NAME_DOT_DOT_SLASH'] = 'Nem lehet ../ a n&eacute;vben';
 $MESSAGE['MEDIA_NAME_INDEX_PHP'] = 'Nem lehet index.php a n&eacute;v';
@@ -539,9 +539,9 @@
 $MESSAGE['MEDIA_SINGLE_UPLOADED'] = ' file sikeresen felt&ouml;ltve';
 $MESSAGE['MEDIA_TARGET_DOT_DOT_SLASH'] = 'Nem lehet ../ in k&ouml;nyvt&aacute;r n&eacute;vben';
 $MESSAGE['MEDIA_UPLOADED'] = ' file sikeresen felt&ouml;ltve';
-$MESSAGE['MOD_FORM_EXCESS_SUBMISSIONS'] = 'Sajn&aacute;ljuk, de ez az ╨Х┬▒rlap t&uacute;l sokszor lett kit&ouml;ltve egy &oacute;ran bel&uuml;l! K&eacute;rem pr&oacute;b&aacute;lja meg egy &oacute;ra m&uacute;lva';
+$MESSAGE['MOD_FORM_EXCESS_SUBMISSIONS'] = 'Sajn&aacute;ljuk, de ez az -?-¦rlap t&uacute;l sokszor lett kit&ouml;ltve egy &oacute;ran bel&uuml;l! K&eacute;rem pr&oacute;b&aacute;lja meg egy &oacute;ra m&uacute;lva';
 $MESSAGE['MOD_FORM_INCORRECT_CAPTCHA'] = 'A megadott ellen&ouml;rz&agrave;k&oacute;d (vagy m&aacute;s n&eacute;ven Captcha) hib&aacute;s. Ha probl&eacute;m&aacute;d van elolvasni a Captcha k&oacute;dot, k&uuml;mailt ide: <a href="mailto:'.SERVER_EMAIL.'">'.SERVER_EMAIL.'</a>';
-$MESSAGE['MOD_FORM_REQUIRED_FIELDS'] = 'A k&ouml;vetkez&agrave;mez╨Ф┬лet k&ouml;telez&agrave;kit&ouml;ltenie';
+$MESSAGE['MOD_FORM_REQUIRED_FIELDS'] = 'A k&ouml;vetkez&agrave;mez-?-?et k&ouml;telez&agrave;kit&ouml;ltenie';
 $MESSAGE['PAGES_ADDED'] = 'Lap sikeresen hozz&aacute;adva';
 $MESSAGE['PAGES_ADDED_HEADING'] = 'Lap c&iacute;msor sikeresen hozz&aacute;adva';
 $MESSAGE['PAGES_BLANK_MENU_TITLE'] = 'K&eacute;rem adjon meg men&uuml; nevet';
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = '&curren;v a WebsiteBaker Admin fel&uuml;let&eacute;n';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Figyelem: A sablon megv&aacute;ltoztat&aacute;s&aacute;t a be&aacute;ll&iacute;t&aacute;sokban teheti meg';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Felhaszn&aacute;l&oacute; sikeresen hozz&aacute;adva';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Figyelem: A jelsz&oacute;t itt csak annak megv&aacute;ltoztat&aacute;sakor kell megadni';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/IT.php
===================================================================
--- branches/2.8.x/wb/languages/IT.php	(revision 1550)
+++ branches/2.8.x/wb/languages/IT.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Benvenuto alla pagina di Amministrazione di WebsiteBaker';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Per cambiare il Template andare alla sezione Impostazioni';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Utente aggiunto';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Attenzione: devi inserire solo valori validi se vuoi cambiare la password utente';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/NO.php
===================================================================
--- branches/2.8.x/wb/languages/NO.php	(revision 1550)
+++ branches/2.8.x/wb/languages/NO.php	(revision 1551)
@@ -631,6 +631,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Velkommen til WebsiteBaker Administrasjon';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Merk: For &aring; endre malen m&aring; man gj&oslash;re dette i Instillinger seksjonen';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Lykkes &aring; opprette ny bruker';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Handlingen ble forkastet. Du kan ikke slette deg selv!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Merk: Skriv kun inn verdier i feltene ovenfor hvis du vil endre passordet til denne brukeren';
@@ -666,4 +675,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/SK.php
===================================================================
--- branches/2.8.x/wb/languages/SK.php	(revision 1550)
+++ branches/2.8.x/wb/languages/SK.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Vitajte v administrat&iacute;vnej &#269;asti';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Pozn.: zmena &#353;ablony sa prov&aacute;dza v sekcii Nastavenia';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'U&#382;&iacute;vate&#318; bol &uacute;spe&#353;ne pridan&yacute;';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Pozn.: vypl&#328;te iba hodnoty hore pokia&#318; si prajete zmeni&#357; heslo';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/LV.php
===================================================================
--- branches/2.8.x/wb/languages/LV.php	(revision 1550)
+++ branches/2.8.x/wb/languages/LV.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Esi sveicinats WebsiteBaker administracija';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Ludzu iegaume: lai mainitu &scaron;ablonu, jadotas uz iestatijumu sadalu';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Lietotajs veiksmigi pievienots';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Ludzu iegaume: Vertibas jaievada augstak redzamajos laukos, ja gribas nomainit &scaron;i lietotaja paroli';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/CA.php
===================================================================
--- branches/2.8.x/wb/languages/CA.php	(revision 1550)
+++ branches/2.8.x/wb/languages/CA.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Benvingut/da al Panell de Control de WebsiteBaker';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Av&iacute;s: per a canviar la plantilla heu d\'anar a la secci&oacute; Par&agrave;metres';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Usuari afegit amb &egrave;xit';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Av&iacute;s: Nom&eacute;s haur&iacute;eu d\'introduir valors als camps superiors si voleu canviar aquestes contrasenyes d\'usuari';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/PT.php
===================================================================
--- branches/2.8.x/wb/languages/PT.php	(revision 1550)
+++ branches/2.8.x/wb/languages/PT.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Bem-Vindo &agrave; Administra&ccdil;&atilde;o do WebsiteBaker';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Aten&ccdil;&atilde;o: para alterar o tema (template) voc&ecirc; precisa ir at&eacute; a sess&atilde;o Configura&ccdil;&otilde;es';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Usu&aacute;rio adicionado com sucesso';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Aten&ccdil;&atilde;o: Voc&ecirc; deve preencher os campos abaixo se deseja alterar a senha';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/DA.php
===================================================================
--- branches/2.8.x/wb/languages/DA.php	(revision 1550)
+++ branches/2.8.x/wb/languages/DA.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Velkommen til administration af din WebsiteBaker';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'OBS: For at &aelig;ndre skabelonen skal du g&aring; til punktet indstillinger';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Brugeren er oprettet';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Funktionen udf&oslash;res ikke - du kan ikke slette dig selv';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'OBS! Du skal kun indtaste v&aelig;rdier i felterne ovenfor, s&aring;fremt du &oslash;nsker at &aelig;ndre denne brugers adgangskode';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/TR.php
===================================================================
--- branches/2.8.x/wb/languages/TR.php	(revision 1550)
+++ branches/2.8.x/wb/languages/TR.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Ho&thorn;geldiniz WebsiteBaker Y&ouml;netimine';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Please note: to change the template you must go to the Settings section';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = 'Kullan&yacute;c&yacute;, ba&thorn;ar&yacute;l&yacute; bir &thorn;ekilde ekledi';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Not Edin: Sen sadece yukar&yacute;daki alanlara de&eth;erleri gir. E&eth;er bu kullan&yacute;c&yacute;lar&yacute; dile de&eth;i&thorn;tirseydin.';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/RU.php
===================================================================
--- branches/2.8.x/wb/languages/RU.php	(revision 1550)
+++ branches/2.8.x/wb/languages/RU.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = '&#1044;&#1086;&#1073;&#1088;&#1086; &#1087;&#1086;&#1078;&#1072;&#1083;&#1086;&#1074;&#1072;&#1090;&#1100; &#1074; &#1052;&#1077;&#1085;&#1102; &#1040;&#1076;&#1084;&#1080;&#1085;&#1080;&#1089;&#1090;&#1088;&#1080;&#1088;&#1086;&#1074;&#1072;&#1085;&#1080;&#1103; &#1057;&#1072;&#1081;&#1090;&#1072;';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = '&#1042;&#1085;&#1080;&#1084;&#1072;&#1085;&#1080;&#1077;! &#1063;&#1090;&#1086;&#1073;&#1099; &#1095;&#1090;&#1086;&#1073;&#1099; &#1089;&#1084;&#1077;&#1085;&#1080;&#1090;&#1100; &#1096;&#1072;&#1073;&#1083;&#1086;&#1085; &#1087;&#1077;&#1088;&#1077;&#1081;&#1076;&#1080;&#1090;&#1077; &#1074; &#1088;&#1072;&#1079;&#1076;&#1077;&#1083; "&#1059;&#1089;&#1090;&#1072;&#1085;&#1086;&#1074;&#1082;&#1080;"';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = '&#1055;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100; &#1076;&#1086;&#1073;&#1072;&#1074;&#1083;&#1077;&#1085; &#1091;&#1089;&#1087;&#1077;&#1096;&#1085;&#1086;';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = '&#1048;&#1084;&#1077;&#1081;&#1090;&#1077; &#1074;&#1074;&#1080;&#1076;&#1091;, &#1095;&#1090;&#1086; &#1074;&#1072;&#1084; &#1089;&#1083;&#1077;&#1076;&#1091;&#1077;&#1090; &#1074;&#1074;&#1077;&#1089;&#1090;&#1080; &#1079;&#1085;&#1072;&#1095;&#1077;&#1085;&#1080;&#1103; &#1090;&#1086;&#1083;&#1100;&#1082;&#1086; &#1074; &#1074;&#1077;&#1088;&#1093;&#1085;&#1080;&#1093; &#1087;&#1086;&#1083;&#1103;&#1093; &#1077;&#1089;&#1083;&#1080; &#1074;&#1099; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1080;&#1079;&#1084;&#1077;&#1085;&#1080;&#1090;&#1100; &#1087;&#1072;&#1088;&#1086;&#1083;&#1100;';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-
Index: branches/2.8.x/wb/languages/DE.php
===================================================================
--- branches/2.8.x/wb/languages/DE.php	(revision 1550)
+++ branches/2.8.x/wb/languages/DE.php	(revision 1551)
@@ -499,7 +499,7 @@
 $MESSAGE['GENERIC_VERSION_COMPARE'] = 'Versionsabgleich';
 $MESSAGE['GENERIC_VERSION_GT'] = 'Upgrade erforderlich!';
 $MESSAGE['GENERIC_VERSION_LT'] = 'Downgrade';
-$MESSAGE['GENERIC_WEBSITE_LOCKED'] = 'Diese Seite ist für Wartungsarbeiten vor&uuml;bergehend geschlossen';
+$MESSAGE['GENERIC_WEBSITE_LOCKED'] = 'Diese Seite ist f&uuml;r Wartungsarbeiten vor&uuml;bergehend geschlossen';
 $MESSAGE['GENERIC_WEBSITE_UNDER_CONSTRUCTION'] = 'Momentan in Bearbeitung';
 $MESSAGE['GROUPS_ADDED'] = 'Die Gruppe wurde erfolgreich hinzugef&uuml;gt';
 $MESSAGE['GROUPS_CONFIRM_DELETE'] = 'Sind Sie sicher, dass Sie die ausgew&auml;hlte Gruppe l&ouml;schen m&ouml;chten (und alle Benutzer, die dazugeh&ouml;ren)?';
@@ -632,6 +632,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Bitte die Datei "upgrade-script.php" vom Webserver l&ouml;schen.';
 $MESSAGE['START_WELCOME_MESSAGE'] = 'Willkommen in der WebsiteBaker Verwaltung';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = 'Bitte beachten Sie: Um eine andere Designvorlage auszuw&auml;hlen, benutzen Sie den Bereich "Optionen"';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unbekannter Upload Fehler';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Konnte Datei nicht schreiben. Fehlende Schreibrechte.';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'Erweiterungsfehler';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'Die hochgeladene Datei &uum;berschreitet die in dem HTML Formular mittels der Anweisung MAX_FILE_SIZE angegebene maximale Dateigr&oum;sse. ';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'Die hochgeladene Datei &uum;berschreitet die in der Anweisung upload_max_filesize in php.ini festgelegte Gr&oum;sse';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'Es wurde keine Datei hochgeladen';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Fehlender Temporäre Ordner';
+$MESSAGE['UPLOAD_ERR_OK'] = 'Die Datei wurde erfolgreich hochgeladen';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'Die Datei wurde nur teilweise hochgeladen';
 $MESSAGE['USERS_ADDED'] = 'Der Benutzer wurde erfolgreich hinzugef&uuml;gt';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Funktion abgelehnt, Sie k&ouml;nnen sich nicht selbst l&ouml;schen!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = 'Bitte beachten Sie: Sie sollten in die obigen Felder nur Werte eingeben, wenn Sie das Passwort dieses Benutzers &auml;ndern m&ouml;chten';
Index: branches/2.8.x/wb/languages/BG.php
===================================================================
--- branches/2.8.x/wb/languages/BG.php	(revision 1550)
+++ branches/2.8.x/wb/languages/BG.php	(revision 1551)
@@ -635,6 +635,15 @@
 $MESSAGE['START_UPGRADE_SCRIPT_EXISTS'] = 'Please delete the file "upgrade-script.php" from your webspace.';
 $MESSAGE['START_WELCOME_MESSAGE'] = '&#1044;&#1086;&#1073;&#1088;&#1077; &#1076;&#1086;&#1096;&#1083;&#1080; &#1074; &#1040;&#1084;&#1080;&#1085;&#1080;&#1089;&#1090;&#1088;&#1072;&#1090;&#1080;&#1074;&#1085;&#1072;&#1090;&#1072; &#1089;&#1090;&#1088;&#1072;&#1085;&#1080;&#1094;&#1072; &#1085;&#1072; WebsiteBaker';
 $MESSAGE['TEMPLATES_CHANGE_TEMPLATE_NOTICE'] = '&#1042;&#1085;&#1080;&#1084;&#1072;&#1085;&#1080;&#1077;: &#1079;&#1072; &#1076;&#1072; &#1089;&#1084;&#1077;&#1085;&#1080;&#1090;&#1077; &#1096;&#1072;&#1073;&#1083;&#1086;&#1085;&#1072; &#1086;&#1090;&#1080;&#1076;&#1077;&#1090;&#1077; &#1074; &#1085;&#1072;&#1089;&#1090;&#1088;&#1086;&#1081;&#1082;&#1080;';
+$MESSAGE['UNKNOW_UPLOAD_ERROR'] = 'Unknown upload error';
+$MESSAGE['UPLOAD_ERR_CANT_WRITE'] = 'Failed to write file to disk';
+$MESSAGE['UPLOAD_ERR_EXTENSION'] = 'File upload stopped by extension';
+$MESSAGE['UPLOAD_ERR_FORM_SIZE'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
+$MESSAGE['UPLOAD_ERR_INI_SIZE'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
+$MESSAGE['UPLOAD_ERR_NO_FILE'] = 'No file was uploaded';
+$MESSAGE['UPLOAD_ERR_NO_TMP_DIR'] = 'Missing a temporary folder';
+$MESSAGE['UPLOAD_ERR_OK'] = 'File were successful uploaded';
+$MESSAGE['UPLOAD_ERR_PARTIAL'] = 'The uploaded file was only partially uploaded';
 $MESSAGE['USERS_ADDED'] = '&#1055;&#1086;&#1090;&#1088;&#1077;&#1073;&#1080;&#1090;&#1077;&#1083;&#1103; &#1077; &#1076;&#1086;&#1073;&#1072;&#1074;&#1077;&#1085; &#1091;&#1089;&#1087;&#1077;&#1096;&#1085;&#1086;';
 $MESSAGE['USERS_CANT_SELFDELETE'] = 'Function rejected, You can not delete yourself!';
 $MESSAGE['USERS_CHANGING_PASSWORD'] = '&#1042;&#1085;&#1080;&#1084;&#1072;&#1085;&#1080;&#1077;: &#1042;&#1098;&#1074;&#1077;&#1076;&#1077;&#1090;&#1077; &#1076;&#1072;&#1085;&#1085;&#1080; &#1074; &#1087;&#1086;&#1083;&#1077;&#1090;&#1072;&#1090;&#1072; &#1072;&#1082;&#1086; &#1080;&#1089;&#1082;&#1072;&#1090;&#1077; &#1076;&#1072; &#1089;&#1084;&#1077;&#1085;&#1080;&#1090;&#1077; &#1087;&#1072;&#1088;&#1086;&#1083;&#1080;&#1090;&#1077; &#1085;&#1072; &#1090;&#1077;&#1079;&#1080; &#1087;&#1086;&#1090;&#1088;&#1077;&#1073;&#1080;&#1090;&#1077;&#1083;&#1080;';
@@ -670,4 +679,3 @@
 {
 	include(WB_PATH.'/languages/old.format.inc.php');
 }
-

Index: branches/2.8.x/wb/account/forgot_form.php
===================================================================
--- branches/2.8.x/wb/account/forgot_form.php	(revision 1550)
+++ branches/2.8.x/wb/account/forgot_form.php	(revision 1551)
@@ -4,7 +4,6 @@
  * @category        frontend
  * @package         account
  * @author          WebsiteBaker Project
- * @copyright       2004-2009, Ryan Djurovich
  * @copyright       2009-2011, Website Baker Org. e.V.
  * @link			http://www.websitebaker2.org/
  * @license         http://www.gnu.org/licenses/gpl.html
@@ -18,88 +17,83 @@
 
 // Must include code to stop this file being access directly
 if(defined('WB_PATH') == false) { die("Cannot access this file directly"); }
-
-// Create new database object
-// $database = new database();
-
 // Check if the user has already submitted the form, otherwise show it
 if(isset($_POST['email']) && $_POST['email'] != "" &&
-    preg_match("/([0-9a-zA-Z]+[-._+&])*[0-9a-zA-Z]+@([-0-9a-zA-Z]+[.])+[a-zA-Z]{2,6}/i", $_POST['email'])) {
+    preg_match("/([0-9a-zA-Z]+[-._+&])*[0-9a-zA-Z]+@([-0-9a-zA-Z]+[.])+[a-zA-Z]{2,6}/i", $_POST['email']))
+{
 	$email = strip_tags($_POST['email']);
-	
-	// Check if the email exists in the database
-	$query = "SELECT user_id,username,display_name,email,last_reset,password FROM ".TABLE_PREFIX."users WHERE email = '".$wb->add_slashes($_POST['email'])."'";
-	$results = $database->query($query);
+// Check if the email exists in the database
+	$sql  = 'SELECT `user_id`,`username`,`display_name`,`email`,`last_reset`,`password` '.
+	        'FROM `'.TABLE_PREFIX.'users` '.
+	        'WHERE `email`=\''.$wb->add_slashes($_POST['email']).'\'';
+	if(($results = $database->query($sql)))
+	{
+		if(($results_array = $results->fetchRow()))
 	if($results->numRows() > 0) {
 	
-		// Get the id, username, email, and last_reset from the above db query
-		$results_array = $results->fetchRow();
-		
+		{ // Get the id, username, email, and last_reset from the above db query
 		// Check if the password has been reset in the last 2 hours
-		$last_reset = $results_array['last_reset'];
-		$time_diff = time()-$last_reset; // Time since last reset in seconds
-		$time_diff = $time_diff/60/60; // Time since last reset in hours
-		if($time_diff < 2) {
-			
+			if( (time() - (int)$results_array['last_reset']) < (2 * 3600) ) {
 			// Tell the user that their password cannot be reset more than once per hour
-			$message = $MESSAGE['FORGOT_PASS']['ALREADY_RESET'];
-			
-		} else {
-		
-			$old_pass = $results_array['password'];
-
+				$message = $MESSAGE['FORGOT_PASS']['ALREADY_RESET'];
+			} else {
+				require_once(WB_PATH.'/framework/PasswordHash.php');
+				$pwh = new PasswordHash(0, true);
+				$old_pass = $results_array['password'];
 			// Generate a random password then update the database with it
-			$new_pass = '';
-			$salt = "abchefghjkmnpqrstuvwxyz0123456789";
-			srand((double)microtime()*1000000);
-			$i = 0;
-			while ($i <= 7) {
-				$num = rand() % 33;
-				$tmp = substr($salt, $num, 1);
-				$new_pass = $new_pass . $tmp;
-				$i++;
-			}
-			$database->query("UPDATE ".TABLE_PREFIX."users SET password = '".md5($new_pass)."', last_reset = '".time()."' WHERE user_id = '".$results_array['user_id']."'");
-			
-			if($database->is_error()) {
-				// Error updating database
-				$message = $database->get_error();
-			} else {
-				// Setup email to send
-				$mail_to = $email;
-				$mail_subject = $MESSAGE['SIGNUP2']['SUBJECT_LOGIN_INFO'];
-
+				$new_pass = $pwh->NewPassword();
+				$sql = 'UPDATE `'.TABLE_PREFIX.'users` '.
+				       'SET `password`=\''.$pwh->HashPassword($new_pass, true).'\', '.
+				           '`last_reset`='.time().' '.
+				       'WHERE `user_id`='.(int)$results_array['user_id'];
+				unset($pwh); // destroy $pwh-Object
+				if($database->query($sql))
+				{ // Setup email to send
+					$mail_to = $email;
+					$mail_subject = $MESSAGE['SIGNUP2_SUBJECT_LOGIN_INFO'];
 				// Replace placeholders from language variable with values
-				$search = array('{LOGIN_DISPLAY_NAME}', '{LOGIN_WEBSITE_TITLE}', '{LOGIN_NAME}', '{LOGIN_PASSWORD}');
-				$replace = array($results_array['display_name'], WEBSITE_TITLE, $results_array['username'], $new_pass); 
-				$mail_message = str_replace($search, $replace, $MESSAGE['SIGNUP2']['BODY_LOGIN_FORGOT']);
-
+					$search = array('{LOGIN_DISPLAY_NAME}', '{LOGIN_WEBSITE_TITLE}', '{LOGIN_NAME}', '{LOGIN_PASSWORD}');
+					$replace = array($results_array['display_name'], WEBSITE_TITLE, $results_array['username'], $new_pass);
+					$mail_message = str_replace($search, $replace, $MESSAGE['SIGNUP2_BODY_LOGIN_FORGOT']);
 				// Try sending the email
-				if($wb->mail(SERVER_EMAIL,$mail_to,$mail_subject,$mail_message)) { 
-					$message = $MESSAGE['FORGOT_PASS']['PASSWORD_RESET'];
-					$display_form = false;
-				} else {
-					$database->query("UPDATE ".TABLE_PREFIX."users SET password = '".$old_pass."' WHERE user_id = '".$results_array['user_id']."'");
-					$message = $MESSAGE['FORGOT_PASS']['CANNOT_EMAIL'];
+					if($wb->mail(SERVER_EMAIL,$mail_to,$mail_subject,$mail_message)) {
+						$message = $MESSAGE['FORGOT_PASS_PASSWORD_RESET'];
+						$display_form = false;
+					}else { // snd mail failed, rollback
+						$sql = 'UPDATE `'.TABLE_PREFIX.'users` '.
+						       'SET `password`=\''.$old_pass.'\' '.
+						       'WHERE `user_id`='.(int)$results_array['user_id'];
+						$database->query($sql);
+						$message = $MESSAGE['FORGOT_PASS_CANNOT_EMAIL'];
+					}
+				}else { // Error updating database
+					$message = $MESSAGE['RECORD_MODIFIED_FAILED'];
+					if(DEBUG) {
+						$message .= '<br />'.$database->get_error();
+						$message .= '<br />'.$sql;
+					}
 				}
 			}
-		
+		}else { // no record found - Email doesn't exist, so tell the user
+			$message = $MESSAGE['FORGOT_PASS_EMAIL_NOT_FOUND'];
 		}
-
-	} else {
-		// Email doesn't exist, so tell the user
-		$message = $MESSAGE['FORGOT_PASS']['EMAIL_NOT_FOUND'];
+	} else { // Query failed
+		$message = 'SystemError:: Database query failed!';
+		if(DEBUG) {
+			$message .= '<br />'.$database->get_error();
+			$message .= '<br />'.$sql;
+		}
 	}
-	
 } else {
 	$email = '';
 }
 
-if(!isset($message)) {
+if(isset($message) && $message != '') {
 	$message = $MESSAGE['FORGOT_PASS']['NO_DATA'];
+	$message_color = 'FF0000';
+} else {
+	$message = $MESSAGE['FORGOT_PASS_NO_DATA'];
 	$message_color = '000000';
-} else {
-	$message_color = 'FF0000';
 }
 
 $_SESSION['PAGE_LINK'] = get_page_link( $_SESSION['PAGE_ID'] );
@@ -110,7 +104,6 @@
 	<button type="button" value="cancel" onClick="javascript: window.location = '<?php print $_SESSION['HTTP_REFERER'] ?>';"><?php print $TEXT['CANCEL'] ?></button>
 </div>
 <h1 style="text-align: center;"><?php echo $MENU['FORGOT']; ?></h1>
-
 <form name="forgot_pass" action="<?php echo WB_URL.'/account/forgot.php'; ?>" method="post">
 	<input type="hidden" name="url" value="{URL}" />
 		<table cellpadding="5" cellspacing="0" border="0" align="center" width="500">
@@ -119,7 +112,7 @@
 			<?php echo $message; ?>
 			</td>
 		</tr>
-		<?php if(!isset($display_form) OR $display_form != false) { ?>
+<?php if(!isset($display_form) OR $display_form != false) { ?>
 		<tr>
 			<td height="10" colspan="2"></td>
 		</tr>
@@ -128,14 +121,6 @@
 			<td><input type="text" maxlength="255" name="email" value="<?php echo $email; ?>" style="width: 180px;" /></td>
 			<td><input type="submit" name="submit" value="<?php echo $TEXT['SEND_DETAILS']; ?>" style="width: 180px; font-size: 10px; color: #003366; border: 1px solid #336699; background-color: #DDDDDD; padding: 3px; text-transform: uppercase;" /></td>
 		</tr>
-<!--
-		<tr>
-			<td>&nbsp;</td>
-		</tr>
-		<tr style="display: {DISPLAY_FORM}">
-			<td height="10" colspan="2"></td>
-		</tr>
--->
-		<?php } ?>
+<?php } ?>
 		</table>
 </form>
\ No newline at end of file